@@ -1,4 +1,4 @@
-"""Application configuration for ``bgjobs`` app."""
+"""Application configuration for bgjobs app"""
 
 from django.apps import AppConfig
 
