@@ -1,5 +1,7 @@
 """Email creation and sending for the projectroles app"""
+
 import logging
+import re
 
 from django.conf import settings
 from django.contrib import auth, messages
@@ -7,21 +9,24 @@ from django.core.mail import EmailMessage
 from django.urls import reverse
 from django.utils.timezone import localtime
 
+from projectroles.app_settings import AppSettingAPI
 from projectroles.utils import build_invite_url, get_display_name
 
 
-# Access Django user model
+app_settings = AppSettingAPI()
+logger = logging.getLogger(__name__)
 User = auth.get_user_model()
 
+
 # Settings
-SUBJECT_PREFIX = settings.EMAIL_SUBJECT_PREFIX
+SUBJECT_PREFIX = settings.EMAIL_SUBJECT_PREFIX.strip() + ' '
 EMAIL_SENDER = settings.EMAIL_SENDER
 DEBUG = settings.DEBUG
 SITE_TITLE = settings.SITE_INSTANCE_TITLE
 ADMIN_RECIPIENT = settings.ADMINS[0]
 
-
-logger = logging.getLogger(__name__)
+# Local constants
+EMAIL_RE = re.compile(r'(^[a-zA-Z0-9_.+-]+@[a-zA-Z0-9-]+\.[a-zA-Z0-9-.]+$)')
 
 
 # Generic Elements -------------------------------------------------------------
@@ -57,7 +62,7 @@ SUBJECT_ROLE_UPDATE = 'Membership changed in {project_label} "{project}"'
 SUBJECT_ROLE_DELETE = 'Membership removed from {project_label} "{project}"'
 
 MESSAGE_ROLE_CREATE = r'''
-{issuer_name} ({issuer_email}) has granted you the membership
+{issuer} has granted you the membership
 in {project_label} "{project}" with the role of "{role}".
 
 To access the {project_label} in {site_title}, please click on
@@ -66,7 +71,7 @@ the following link:
 '''.lstrip()
 
 MESSAGE_ROLE_UPDATE = r'''
-{issuer_name} ({issuer_email}) has changed your membership
+{issuer} has changed your membership
 role in {project_label} "{project}" into "{role}".
 
 To access the {project_label} in {site_title}, please click on
@@ -75,8 +80,7 @@ the following link:
 '''.lstrip()
 
 MESSAGE_ROLE_DELETE = r'''
-{issuer_name} ({issuer_email}) has removed your membership
-from {project_label} "{project}".
+{issuer} has removed your membership from {project_label} "{project}".
 '''.lstrip()
 
 
@@ -86,7 +90,7 @@ from {project_label} "{project}".
 SUBJECT_INVITE = 'Invitation for {project_label} "{project}"'
 
 MESSAGE_INVITE_BODY = r'''
-You have been invited by {issuer_name} ({issuer_email})
+You have been invited by {issuer}
 to share data in the {project_label} "{project}" with the
 role of "{role}".
 
@@ -112,13 +116,11 @@ Message from the sender of this invitation:
 # Invite Acceptance Notification Template --------------------------------------
 
 
-SUBJECT_ACCEPT = (
-    'Invitation accepted by {user_name} for {project_label} "{project}"'
-)
+SUBJECT_ACCEPT = 'Invitation accepted by {user} for {project_label} "{project}"'
 
 MESSAGE_ACCEPT_BODY = r'''
 Invitation sent by you for role of "{role}" in {project_label} "{project}"
-has been accepted by {user_name} ({user_email}).
+has been accepted by {user}.
 They have been granted access in the {project_label} accordingly.
 '''.lstrip()
 
@@ -143,16 +145,16 @@ to grant the user access to the {project_label}.
 # Project/Category Creation Notification Template ------------------------------
 
 
-SUBJECT_PROJECT_CREATE = '{project_type} "{project}" created by {user_name}'
+SUBJECT_PROJECT_CREATE = '{project_type} "{project}" created by {user}'
 
 MESSAGE_PROJECT_CREATE_BODY = r'''
-{user_name} ({user_email}) has created a new {project_type}
+{user} has created a new {project_type}
 under "{category}".
 You are receiving this email because you are the owner of the parent category.
 You have automatically inherited owner rights to the created {project_type}.
 
 Title: {project}
-Owner: {owner_name} ({owner_email})
+Owner: {owner}
 
 You can access the project at the following link:
 {project_url}
@@ -162,16 +164,16 @@ You can access the project at the following link:
 # Project/Category Moving Notification Template ------------------------------
 
 
-SUBJECT_PROJECT_MOVE = '{project_type} "{project}" moved by {user_name}'
+SUBJECT_PROJECT_MOVE = '{project_type} "{project}" moved by {user}'
 
 MESSAGE_PROJECT_MOVE_BODY = r'''
-{user_name} ({user_email}) has moved the {project_type} "{project}"
+{user} has moved the {project_type} "{project}"
 under "{category}".
 You are receiving this email because you are the owner of the parent category.
 You have automatically inherited owner rights to the created {project_type}.
 
 Title: {project}
-Owner: {owner_name} ({owner_email})
+Owner: {owner}
 
 You can access the project at the following link:
 {project_url}
@@ -181,6 +183,19 @@ You can access the project at the following link:
 # Email composing helpers ------------------------------------------------------
 
 
+def get_email_user(user):
+    """
+    Return a string representation of a user object for emails.
+
+    :param user: SODARUser object
+    :return: string
+    """
+    ret = user.get_full_name()
+    if user.email:
+        ret += ' ({})'.format(user.email)
+    return ret
+
+
 def get_invite_body(project, issuer, role_name, invite_url, date_expire_str):
     """
     Return the invite content header.
@@ -194,8 +209,7 @@ def get_invite_body(project, issuer, role_name, invite_url, date_expire_str):
     """
     body = MESSAGE_HEADER_NO_RECIPIENT.format(site_title=SITE_TITLE)
     body += MESSAGE_INVITE_BODY.format(
-        issuer_name=issuer.get_full_name(),
-        issuer_email=issuer.email,
+        issuer=get_email_user(issuer),
         project=project.title,
         role=role_name,
         invite_url=invite_url,
@@ -220,12 +234,24 @@ def get_invite_message(message=None):
     return ''
 
 
-def get_email_footer():
+def get_email_header(header):
     """
-    Return the invite content footer.
+    Return the email header.
 
     :return: string
     """
+    return getattr(settings, 'PROJECTROLES_EMAIL_HEADER', None) or header
+
+
+def get_email_footer():
+    """
+    Return the email footer.
+
+    :return: string
+    """
+    custom_footer = getattr(settings, 'PROJECTROLES_EMAIL_FOOTER', None)
+    if custom_footer:
+        return '\n' + custom_footer
     return MESSAGE_FOOTER.format(
         site_title=SITE_TITLE,
         admin_name=ADMIN_RECIPIENT[0],
@@ -240,12 +266,8 @@ def get_invite_subject(project):
     :param project: Project object
     :return: string
     """
-    return (
-        SUBJECT_PREFIX
-        + ' '
-        + SUBJECT_INVITE.format(
-            project=project.title, project_label=get_display_name(project.type)
-        )
+    return SUBJECT_PREFIX + SUBJECT_INVITE.format(
+        project=project.title, project_label=get_display_name(project.type)
     )
 
 
@@ -257,7 +279,7 @@ def get_role_change_subject(change_type, project):
     :param project: Project object
     :return: String
     """
-    subject = SUBJECT_PREFIX + ' '
+    subject = SUBJECT_PREFIX
     subject_kwargs = {
         'project': project.title,
         'project_label': get_display_name(project.type),
@@ -285,12 +307,13 @@ def get_role_change_body(
     :param project_url: URL for the project
     :return: String
     """
-    body = MESSAGE_HEADER.format(recipient=user_name, site_title=SITE_TITLE)
+    body = get_email_header(
+        MESSAGE_HEADER.format(recipient=user_name, site_title=SITE_TITLE)
+    )
 
     if change_type == 'create':
         body += MESSAGE_ROLE_CREATE.format(
-            issuer_name=issuer.get_full_name(),
-            issuer_email=issuer.email,
+            issuer=get_email_user(issuer),
             role=role_name,
             project=project.title,
             project_url=project_url,
@@ -300,8 +323,7 @@ def get_role_change_body(
 
     elif change_type == 'update':
         body += MESSAGE_ROLE_UPDATE.format(
-            issuer_name=issuer.get_full_name(),
-            issuer_email=issuer.email,
+            issuer=get_email_user(issuer),
             role=role_name,
             project=project.title,
             project_url=project_url,
@@ -311,8 +333,7 @@ def get_role_change_body(
 
     elif change_type == 'delete':
         body += MESSAGE_ROLE_DELETE.format(
-            issuer_name=issuer.get_full_name(),
-            issuer_email=issuer.email,
+            issuer=get_email_user(issuer),
             project=project.title,
             project_label=get_display_name(project.type),
         )
@@ -323,6 +344,36 @@ def get_role_change_body(
     return body
 
 
+def get_user_addr(user):
+    """
+    Return all the email addresses for a user as a list. Emails set with
+    user_email_additional are included. If a user has no main email set but
+    additional emails exist, the latter are returned.
+
+    :param user: User object
+    :return: list
+    """
+
+    def _validate(user, email):
+        if re.match(EMAIL_RE, email):
+            return True
+        logger.error(
+            'Invalid email for user {}: {}'.format(user.username, email)
+        )
+
+    ret = []
+    if user.email and _validate(user, user.email):
+        ret.append(user.email)
+    add_email = app_settings.get_app_setting(
+        'projectroles', 'user_email_additional', user=user
+    )
+    if add_email:
+        for e in add_email.strip().split(';'):
+            if _validate(user, e):
+                ret.append(e)
+    return ret
+
+
 def send_mail(subject, message, recipient_list, request, reply_to=None):
     """
     Wrapper for send_mail() with logging and error messaging.
@@ -385,8 +436,10 @@ def send_role_change_mail(change_type, project, user, role, request):
         issuer=request.user,
         project_url=project_url,
     )
-    reply_to = [request.user.email] if request.user.email else None
-    return send_mail(subject, message, [user.email], request, reply_to)
+    issuer_emails = get_user_addr(request.user)
+    return send_mail(
+        subject, message, get_user_addr(user), request, issuer_emails
+    )
 
 
 def send_invite_mail(invite, request):
@@ -410,8 +463,8 @@ def send_invite_mail(invite, request):
     message += get_invite_message(invite.message)
     message += get_email_footer()
     subject = get_invite_subject(invite.project)
-    reply_to = [invite.issuer.email] if invite.issuer.email else None
-    return send_mail(subject, message, [invite.email], request, reply_to)
+    issuer_emails = get_user_addr(invite.issuer)
+    return send_mail(subject, message, [invite.email], request, issuer_emails)
 
 
 def send_accept_note(invite, request, user):
@@ -423,23 +476,20 @@ def send_accept_note(invite, request, user):
     :param request: HTTP request
     :return: Amount of sent email (int)
     """
-    subject = (
-        SUBJECT_PREFIX
-        + ' '
-        + SUBJECT_ACCEPT.format(
-            user_name=user.get_full_name(),
-            project_label=get_display_name(invite.project.type),
-            project=invite.project.title,
-        )
+    subject = SUBJECT_PREFIX + SUBJECT_ACCEPT.format(
+        user=get_email_user(user),
+        project_label=get_display_name(invite.project.type),
+        project=invite.project.title,
     )
-    message = MESSAGE_HEADER.format(
-        recipient=invite.issuer.get_full_name(), site_title=SITE_TITLE
+    message = get_email_header(
+        MESSAGE_HEADER.format(
+            recipient=invite.issuer.get_full_name(), site_title=SITE_TITLE
+        )
     )
     message += MESSAGE_ACCEPT_BODY.format(
         role=invite.role.name,
         project=invite.project.title,
-        user_name=user.get_full_name(),
-        user_email=user.email,
+        user=get_email_user(user),
         site_title=SITE_TITLE,
         project_label=get_display_name(invite.project.type),
     )
@@ -447,7 +497,7 @@ def send_accept_note(invite, request, user):
     if not settings.PROJECTROLES_EMAIL_SENDER_REPLY:
         message += NO_REPLY_NOTE
     message += get_email_footer()
-    return send_mail(subject, message, [invite.issuer.email], request)
+    return send_mail(subject, message, get_user_addr(invite.issuer), request)
 
 
 def send_expiry_note(invite, request, user_name):
@@ -460,15 +510,13 @@ def send_expiry_note(invite, request, user_name):
     :param user_name: User name of invited user
     :return: Amount of sent email (int)
     """
-    subject = (
-        SUBJECT_PREFIX
-        + ' '
-        + SUBJECT_EXPIRY.format(
-            user_name=user_name, project=invite.project.title
-        )
+    subject = SUBJECT_PREFIX + SUBJECT_EXPIRY.format(
+        user_name=user_name, project=invite.project.title
     )
-    message = MESSAGE_HEADER.format(
-        recipient=invite.issuer.get_full_name(), site_title=SITE_TITLE
+    message = get_email_header(
+        MESSAGE_HEADER.format(
+            recipient=invite.issuer.get_full_name(), site_title=SITE_TITLE
+        )
     )
     message += MESSAGE_EXPIRY_BODY.format(
         role=invite.role.name,
@@ -483,7 +531,7 @@ def send_expiry_note(invite, request, user_name):
     if not settings.PROJECTROLES_EMAIL_SENDER_REPLY:
         message += NO_REPLY_NOTE
     message += get_email_footer()
-    return send_mail(subject, message, [invite.issuer.email], request)
+    return send_mail(subject, message, get_user_addr(invite.issuer), request)
 
 
 def send_project_create_mail(project, request):
@@ -504,19 +552,19 @@ def send_project_create_mail(project, request):
     subject = SUBJECT_PROJECT_CREATE.format(
         project_type=get_display_name(project.type, title=True),
         project=project.title,
-        user_name=request.user.get_full_name(),
+        user=get_email_user(request.user),
     )
-    message = MESSAGE_HEADER.format(
-        recipient=parent_owner.user.get_full_name(), site_title=SITE_TITLE
+    message = get_email_header(
+        MESSAGE_HEADER.format(
+            recipient=parent_owner.user.get_full_name(), site_title=SITE_TITLE
+        )
     )
     message += MESSAGE_PROJECT_CREATE_BODY.format(
-        user_name=request.user.get_full_name(),
-        user_email=request.user.email,
+        user=get_email_user(request.user),
         project_type=get_display_name(project.type),
         category=parent.title,
         project=project.title,
-        owner_name=project_owner.user.get_full_name(),
-        owner_email=project_owner.user.email,
+        owner=get_email_user(project_owner.user),
         project_url=request.build_absolute_uri(
             reverse(
                 'projectroles:detail', kwargs={'project': project.sodar_uuid}
@@ -527,9 +575,9 @@ def send_project_create_mail(project, request):
     return send_mail(
         subject,
         message,
-        [parent_owner.user.email],
+        get_user_addr(parent_owner.user),
         request,
-        reply_to=[request.user.email],
+        reply_to=get_user_addr(request.user),
     )
 
 
@@ -551,19 +599,19 @@ def send_project_move_mail(project, request):
     subject = SUBJECT_PROJECT_MOVE.format(
         project_type=get_display_name(project.type, title=True),
         project=project.title,
-        user_name=request.user.get_full_name(),
+        user=get_email_user(request.user),
     )
-    message = MESSAGE_HEADER.format(
-        recipient=parent_owner.user.get_full_name(), site_title=SITE_TITLE
+    message = get_email_header(
+        MESSAGE_HEADER.format(
+            recipient=parent_owner.user.get_full_name(), site_title=SITE_TITLE
+        )
     )
     message += MESSAGE_PROJECT_MOVE_BODY.format(
-        user_name=request.user.get_full_name(),
-        user_email=request.user.email,
+        user=get_email_user(request.user),
         project_type=get_display_name(project.type),
         category=parent.title,
         project=project.title,
-        owner_name=project_owner.user.get_full_name(),
-        owner_email=project_owner.user.email,
+        owner=get_email_user(project_owner.user),
         project_url=request.build_absolute_uri(
             reverse(
                 'projectroles:detail', kwargs={'project': project.sodar_uuid}
@@ -574,9 +622,9 @@ def send_project_move_mail(project, request):
     return send_mail(
         subject,
         message,
-        [parent_owner.user.email],
+        get_user_addr(parent_owner.user),
         request,
-        reply_to=[request.user.email],
+        reply_to=get_user_addr(request.user),
     )
 
 
@@ -594,24 +642,24 @@ def send_generic_mail(
     :param request: HTTP request
     :return: Amount of mail sent (int)
     """
-    subject = SUBJECT_PREFIX + ' ' + subject_body
+    subject = SUBJECT_PREFIX + subject_body
     ret = 0
 
     for recipient in recipient_list:
         if isinstance(recipient, User):
             recp_name = recipient.get_full_name()
-            recp_email = recipient.email
+            recp_addr = get_user_addr(recipient)
         else:
             recp_name = 'recipient'
-            recp_email = recipient
+            recp_addr = [recipient]
 
-        message = MESSAGE_HEADER.format(
-            recipient=recp_name, site_title=SITE_TITLE
+        message = get_email_header(
+            MESSAGE_HEADER.format(recipient=recp_name, site_title=SITE_TITLE)
         )
         message += message_body
         if not reply_to and not settings.PROJECTROLES_EMAIL_SENDER_REPLY:
             message += NO_REPLY_NOTE
         message += get_email_footer()
-        ret += send_mail(subject, message, [recp_email], request, reply_to)
+        ret += send_mail(subject, message, recp_addr, request, reply_to)
 
     return ret
