@@ -1,9 +1,11 @@
 """Tests for template tags in the projectroles app"""
 
-from importlib import import_module
 import mistune
 import uuid
 
+from importlib import import_module
+from math import ceil
+
 from django.conf import settings
 from django.test import override_settings, RequestFactory
 from django.urls import reverse
@@ -509,8 +511,6 @@ class TestProjectrolesTemplateTags(TestTemplateTagsBase):
             tags.is_app_visible(app_plugin, self.project, superuser), True
         )
 
-    # TODO: Test get_not_found_alert()
-
     def test_is_inherited_owner(self):
         """Test is_inherited_owner()"""
         owner_cat = self.make_user('user_cat_owner')
@@ -561,3 +561,40 @@ class TestProjectrolesTemplateTags(TestTemplateTagsBase):
         self.assertEqual(
             tags.get_sidebar_app_legend('Update Project'), 'Update<br />Project'
         )
+
+    def test_get_sidebar_icon_size(self):
+        """Test get_sidebar_icon_size() with default value"""
+        self.assertEqual(tags.get_sidebar_icon_size(), 36)
+
+    @override_settings(
+        PROJECTROLES_SIDEBAR_ICON_SIZE=tags.SIDEBAR_ICON_MIN_SIZE - 2
+    )
+    def test_get_sidebar_icon_size_min(self):
+        """Test get_sidebar_icon_size() with a value below minimum"""
+        self.assertEqual(
+            tags.get_sidebar_icon_size(), tags.SIDEBAR_ICON_MIN_SIZE
+        )
+
+    @override_settings(
+        PROJECTROLES_SIDEBAR_ICON_SIZE=tags.SIDEBAR_ICON_MAX_SIZE + 2
+    )
+    def test_get_sidebar_icon_size_max(self):
+        """Test get_sidebar_icon_size() with a value over max"""
+        self.assertEqual(
+            tags.get_sidebar_icon_size(), tags.SIDEBAR_ICON_MAX_SIZE
+        )
+
+    def test_get_sidebar_notch_pos(self):
+        """Test get_sidebar_notch_pos()"""
+        self.assertEqual(tags.get_sidebar_notch_pos(), ceil(36 / 3))
+
+    def test_get_sidebar_notch_size(self):
+        """Test get_sidebar_notch_size()"""
+        self.assertEqual(tags.get_sidebar_notch_size(), 12)
+
+    @override_settings(
+        PROJECTROLES_SIDEBAR_ICON_SIZE=tags.SIDEBAR_ICON_MIN_SIZE
+    )
+    def test_get_sidebar_notch_size_min(self):
+        """Test get_sidebar_notch_size() with minimum notch size"""
+        self.assertEqual(tags.get_sidebar_notch_size(), 9)
